==> vtk6-6.3.0-4-armv6h.pkg.tar.xz: vtk/vtkRIBExporter.java <==
// java wrapper for vtkRIBExporter object
//

package vtk;
import vtk.*;

public class vtkRIBExporter extends vtkExporter
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSize_2(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_2(id0,id1); }

  private native void SetSize_3(int id0[]);
  public void SetSize(int id0[])
    { SetSize_3(id0); }

  private native int[]  GetSize_4();
  public int[]  GetSize()
    { return GetSize_4(); }

  private native void SetPixelSamples_5(int id0,int id1);
  public void SetPixelSamples(int id0,int id1)
    { SetPixelSamples_5(id0,id1); }

  private native void SetPixelSamples_6(int id0[]);
  public void SetPixelSamples(int id0[])
    { SetPixelSamples_6(id0); }

  private native int[]  GetPixelSamples_7();
  public int[]  GetPixelSamples()
    { return GetPixelSamples_7(); }

  private native void SetFilePrefix_8(String id0);
  public void SetFilePrefix(String id0)
    { SetFilePrefix_8(id0); }

  private native String GetFilePrefix_9();
  public String GetFilePrefix()
    { return GetFilePrefix_9(); }

  private native void SetTexturePrefix_10(String id0);
  public void SetTexturePrefix(String id0)
    { SetTexturePrefix_10(id0); }

  private native String GetTexturePrefix_11();
  public String GetTexturePrefix()
    { return GetTexturePrefix_11(); }

  private native void SetBackground_12(int id0);
  public void SetBackground(int id0)
    { SetBackground_12(id0); }

  private native int GetBackground_13();
  public int GetBackground()
    { return GetBackground_13(); }

  private native void BackgroundOn_14();
  public void BackgroundOn()
    { BackgroundOn_14(); }

  private native void BackgroundOff_15();
  public void BackgroundOff()
    { BackgroundOff_15(); }

  private native void SetExportArrays_16(int id0);
  public void SetExportArrays(int id0)
    { SetExportArrays_16(id0); }

  private native int GetExportArraysMinValue_17();
  public int GetExportArraysMinValue()
    { return GetExportArraysMinValue_17(); }

  private native int GetExportArraysMaxValue_18();
  public int GetExportArraysMaxValue()
    { return GetExportArraysMaxValue_18(); }

  private native void ExportArraysOn_19();
  public void ExportArraysOn()
    { ExportArraysOn_19(); }

  private native void ExportArraysOff_20();
  public void ExportArraysOff()
    { ExportArraysOff_20(); }

  private native int GetExportArrays_21();
  public int GetExportArrays()
    { return GetExportArrays_21(); }

  public vtkRIBExporter() { super(); }

  public vtkRIBExporter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkRIBExporter.java <==
// java wrapper for vtkRIBExporter object
//

package vtk;
import vtk.*;

public class vtkRIBExporter extends vtkExporter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSize_2(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_2(id0,id1); }

  private native void SetSize_3(int id0[]);
  public void SetSize(int id0[])
    { SetSize_3(id0); }

  private native int[]  GetSize_4();
  public int[]  GetSize()
    { return GetSize_4(); }

  private native void SetPixelSamples_5(int id0,int id1);
  public void SetPixelSamples(int id0,int id1)
    { SetPixelSamples_5(id0,id1); }

  private native void SetPixelSamples_6(int id0[]);
  public void SetPixelSamples(int id0[])
    { SetPixelSamples_6(id0); }

  private native int[]  GetPixelSamples_7();
  public int[]  GetPixelSamples()
    { return GetPixelSamples_7(); }

  private native void SetFilePrefix_8(String id0);
  public void SetFilePrefix(String id0)
    { SetFilePrefix_8(id0); }

  private native String GetFilePrefix_9();
  public String GetFilePrefix()
    { return GetFilePrefix_9(); }

  private native void SetTexturePrefix_10(String id0);
  public void SetTexturePrefix(String id0)
    { SetTexturePrefix_10(id0); }

  private native String GetTexturePrefix_11();
  public String GetTexturePrefix()
    { return GetTexturePrefix_11(); }

  private native void SetBackground_12(int id0);
  public void SetBackground(int id0)
    { SetBackground_12(id0); }

  private native int GetBackground_13();
  public int GetBackground()
    { return GetBackground_13(); }

  private native void BackgroundOn_14();
  public void BackgroundOn()
    { BackgroundOn_14(); }

  private native void BackgroundOff_15();
  public void BackgroundOff()
    { BackgroundOff_15(); }

  private native void SetExportArrays_16(int id0);
  public void SetExportArrays(int id0)
    { SetExportArrays_16(id0); }

  private native int GetExportArraysMinValue_17();
  public int GetExportArraysMinValue()
    { return GetExportArraysMinValue_17(); }

  private native int GetExportArraysMaxValue_18();
  public int GetExportArraysMaxValue()
    { return GetExportArraysMaxValue_18(); }

  private native void ExportArraysOn_19();
  public void ExportArraysOn()
    { ExportArraysOn_19(); }

  private native void ExportArraysOff_20();
  public void ExportArraysOff()
    { ExportArraysOff_20(); }

  private native int GetExportArrays_21();
  public int GetExportArrays()
    { return GetExportArrays_21(); }

  public vtkRIBExporter() { super(); }

  public vtkRIBExporter(long id) { super(id); }
  public native long   VTKInit();

}
